@@ -1,14 +1,15 @@
 name = "labelbox"
-__version__ = "3.13.1"
+__version__ = "3.18.0"
 
-from labelbox.schema.project import Project
 from labelbox.client import Client
+from labelbox.schema.project import Project
 from labelbox.schema.model import Model
 from labelbox.schema.bulk_import_request import BulkImportRequest
 from labelbox.schema.annotation_import import MALPredictionImport, MEAPredictionImport, LabelImport
 from labelbox.schema.dataset import Dataset
 from labelbox.schema.data_row import DataRow
 from labelbox.schema.label import Label
+from labelbox.schema.batch import Batch
 from labelbox.schema.review import Review
 from labelbox.schema.user import User
 from labelbox.schema.organization import Organization
@@ -23,3 +24,5 @@ from labelbox.schema.data_row_metadata import DataRowMetadataOntology
 from labelbox.schema.model_run import ModelRun
 from labelbox.schema.benchmark import Benchmark
 from labelbox.schema.iam_integration import IAMIntegration
+from labelbox.schema.resource_tag import ResourceTag
+from labelbox.schema.project_resource_tag import ProjectResourceTag
