@@ -3,6 +3,7 @@ from typing import Optional, Union, Tuple
 import cv2
 import geojson
 import numpy as np
+from shapely.geometry import Polygon as SPolygon
 
 from .geometry import Geometry
 from .point import Point
@@ -30,6 +31,24 @@ class Rectangle(Geometry):
             [self.start.x, self.start.y],
         ]])
 
+    @classmethod
+    def from_shapely(cls, shapely_obj: SPolygon) -> "Rectangle":
+        """Transforms a shapely object.
+        
+        If the provided shape is a non-rectangular polygon, a rectangle will be
+        returned based on the min and max x,y values."""
+        if not isinstance(shapely_obj, SPolygon):
+            raise TypeError(
+                f"Expected Shapely Polygon. Got {shapely_obj.geom_type}")
+
+        min_x, min_y, max_x, max_y = shapely_obj.bounds
+
+        start = [min_x, min_y]
+        end = [max_x, max_y]
+
+        return Rectangle(start=Point(x=start[0], y=start[1]),
+                         end=Point(x=end[0], y=end[1]))
+
     def draw(self,
              height: Optional[int] = None,
              width: Optional[int] = None,
@@ -55,6 +74,6 @@ class Rectangle(Geometry):
         return cv2.polylines(canvas, pts, True, color, thickness)
 
     @classmethod
-    def from_xyhw(cls, x: float, y: float, h: float, w: float):
+    def from_xyhw(cls, x: float, y: float, h: float, w: float) -> "Rectangle":
         """Create Rectangle from x,y, height width format"""
         return cls(start=Point(x=x, y=y), end=Point(x=x + w, y=y + h))
